Index: src/crankshaft/ppc/lithium-codegen-ppc.cc |
diff --git a/src/crankshaft/ppc/lithium-codegen-ppc.cc b/src/crankshaft/ppc/lithium-codegen-ppc.cc |
index fabb9bbcdacf56c96951c4fd150e861b07186a86..25ed8926879077d65af9a3a6772e10040596b12e 100644 |
--- a/src/crankshaft/ppc/lithium-codegen-ppc.cc |
+++ b/src/crankshaft/ppc/lithium-codegen-ppc.cc |
@@ -3323,11 +3323,13 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
__ bne(&done); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
- __ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
+ __ LoadRoot(result, Heap::kArrayElementsProtectorRootIndex); |
__ LoadP(result, FieldMemOperand(result, Cell::kValueOffset)); |
- __ CmpSmiLiteral(result, Smi::FromInt(Isolate::kArrayProtectorValid), r0); |
+ __ CmpSmiLiteral(result, |
+ Smi::FromInt(Isolate::kArrayElementsProtectorValid), r0); |
DeoptimizeIf(ne, instr, Deoptimizer::kHole); |
} |
__ LoadRoot(result, Heap::kUndefinedValueRootIndex); |
@@ -3323,11 +3323,13 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kArrayElementsProtectorValid. |
+ // Otherwise |
// it needs to bail out. |